import produce from "immer";
import { TransactionHandler } from "./TransactionHandler";
export class TransactionResolver {
    #definition;
    listeners = new Set();
    transactionHandler;
    constructor({ definition }) {
        this.#definition = definition;
        this.transactionHandler = new TransactionHandler(definition);
    }
    get definition() {
        return this.#definition;
    }
    set definition(definition) {
        this.#definition = definition;
    }
    applyTransaction(transaction) {
        return this.applyTransactions([transaction]);
    }
    applyTransactions(transactions) {
        this.definition = produce(this.definition, (draft) => {
            for (const transaction of transactions) {
                this.transactionHandler.applyTransaction(draft, transaction);
            }
        });
        for (const listener of this.listeners.values()) {
            listener(this.definition);
        }
        return this.definition;
    }
    watch(listener) {
        this.listeners.add(listener);
        return () => {
            this.listeners.delete(listener);
        };
    }
}
